diff --git a/contrib/seeds/makeseeds.py b/contrib/seeds/makeseeds.py
--- a/contrib/seeds/makeseeds.py
+++ b/contrib/seeds/makeseeds.py
@@ -34,7 +34,7 @@
     r"^([abcdefghijklmnopqrstuvwxyz234567]{16}\.onion):(\d+)$")
 
 # Used to only select nodes with a user agent string compatible with the
-# BCC/UAHF specification.
+# BCH/UAHF specification.
 PATTERN_AGENT = re.compile(
     r"^(/BitcoinABC:0.16.(\d+)\(\S+\)/|/BitcoinXT:0.11.0G\(\S+\)/|/BUCash:1.1.(\d+)\(\S+\)/|/Classic:1.3.(\d+)\(\S+\)/)")
 
@@ -178,7 +178,7 @@
     # Filter out hosts with multiple bitcoin ports, these are likely abusive
     ips = filtermultiport(ips)
     # Look up ASNs and limit results, both per ASN and globally.
-    # TODO during this bootstrap phase we need any BCC full nodes
+    # TODO during this bootstrap phase we need any BCH full nodes
     # active on the network, uncomment the following line once the
     # BCC chain will be consolidated.
     # ips = filterbyasn(ips, MAX_SEEDS_PER_ASN, NSEEDS)
diff --git a/doc/man/bitcoin-cli.1 b/doc/man/bitcoin-cli.1
--- a/doc/man/bitcoin-cli.1
+++ b/doc/man/bitcoin-cli.1
@@ -3,7 +3,7 @@
 .SH NAME
 bitcoin-cli \- manual page for bitcoin-cli v0.16.0.0
 .SH DESCRIPTION
-Bitcoin ABC RPC client version v0.16.0.0\-c5cfdf732
+Bitcoin ABC RPC client version v0.16.0.0\-64c0c2d35\-dirty
 .SS "Usage:"
 .TP
 bitcoin\-cli [options] <command> [params]
diff --git a/doc/man/bitcoin-qt.1 b/doc/man/bitcoin-qt.1
--- a/doc/man/bitcoin-qt.1
+++ b/doc/man/bitcoin-qt.1
@@ -3,7 +3,7 @@
 .SH NAME
 bitcoin-qt \- manual page for bitcoin-qt v0.16.0.0
 .SH DESCRIPTION
-Bitcoin ABC version v0.16.0.0\-c5cfdf732 (64\-bit)
+Bitcoin ABC version v0.16.0.0\-64c0c2d35\-dirty (64\-bit)
 Usage:
 .IP
 bitcoin\-qt [command\-line options]
@@ -275,17 +275,17 @@
 .HP
 \fB\-fallbackfee=\fR<amt>
 .IP
-A fee rate (in BCC/kB) that will be used when fee estimation has
+A fee rate (in BCH/kB) that will be used when fee estimation has
 insufficient data (default: 0.0002)
 .HP
 \fB\-mintxfee=\fR<amt>
 .IP
-Fees (in BCC/kB) smaller than this are considered zero fee for
+Fees (in BCH/kB) smaller than this are considered zero fee for
 transaction creation (default: 0.00001)
 .HP
 \fB\-paytxfee=\fR<amt>
 .IP
-Fee (in BCC/kB) to add to transactions you send (default: 0.00)
+Fee (in BCH/kB) to add to transactions you send (default: 0.00)
 .HP
 \fB\-rescan\fR
 .IP
@@ -362,12 +362,12 @@
 .HP
 \fB\-minrelaytxfee=\fR<amt>
 .IP
-Fees (in BCC/kB) smaller than this are considered zero fee for relaying,
+Fees (in BCH/kB) smaller than this are considered zero fee for relaying,
 mining and transaction creation (default: 0.00001)
 .HP
 \fB\-maxtxfee=\fR<amt>
 .IP
-Maximum total fees (in BCC) to use in a single wallet transaction or raw
+Maximum total fees (in BCH) to use in a single wallet transaction or raw
 transaction; setting this too low may abort large transactions
 (default: 0.10)
 .HP
@@ -414,7 +414,7 @@
 .HP
 \fB\-blockmintxfee=\fR<amt>
 .IP
-Set lowest fee rate (in BCC/kB) for transactions to be included in block
+Set lowest fee rate (in BCH/kB) for transactions to be included in block
 creation. (default: 0.00001)
 .PP
 RPC server options:
diff --git a/doc/man/bitcoin-tx.1 b/doc/man/bitcoin-tx.1
--- a/doc/man/bitcoin-tx.1
+++ b/doc/man/bitcoin-tx.1
@@ -3,7 +3,7 @@
 .SH NAME
 bitcoin-tx \- manual page for bitcoin-tx v0.16.0.0
 .SH DESCRIPTION
-Bitcoin ABC bitcoin\-tx utility version v0.16.0.0\-c5cfdf732
+Bitcoin ABC bitcoin\-tx utility version v0.16.0.0\-64c0c2d35\-dirty
 .SS "Usage:"
 .TP
 bitcoin\-tx [options] <hex\-tx> [commands]
diff --git a/doc/man/bitcoind.1 b/doc/man/bitcoind.1
--- a/doc/man/bitcoind.1
+++ b/doc/man/bitcoind.1
@@ -3,7 +3,7 @@
 .SH NAME
 bitcoind \- manual page for bitcoind v0.16.0.0
 .SH DESCRIPTION
-Bitcoin ABC Daemon version v0.16.0.0\-c5cfdf732
+Bitcoin ABC Daemon version v0.16.0.0\-64c0c2d35\-dirty
 .SS "Usage:"
 .TP
 bitcoind [options]
@@ -280,17 +280,17 @@
 .HP
 \fB\-fallbackfee=\fR<amt>
 .IP
-A fee rate (in BCC/kB) that will be used when fee estimation has
+A fee rate (in BCH/kB) that will be used when fee estimation has
 insufficient data (default: 0.0002)
 .HP
 \fB\-mintxfee=\fR<amt>
 .IP
-Fees (in BCC/kB) smaller than this are considered zero fee for
+Fees (in BCH/kB) smaller than this are considered zero fee for
 transaction creation (default: 0.00001)
 .HP
 \fB\-paytxfee=\fR<amt>
 .IP
-Fee (in BCC/kB) to add to transactions you send (default: 0.00)
+Fee (in BCH/kB) to add to transactions you send (default: 0.00)
 .HP
 \fB\-rescan\fR
 .IP
@@ -367,12 +367,12 @@
 .HP
 \fB\-minrelaytxfee=\fR<amt>
 .IP
-Fees (in BCC/kB) smaller than this are considered zero fee for relaying,
+Fees (in BCH/kB) smaller than this are considered zero fee for relaying,
 mining and transaction creation (default: 0.00001)
 .HP
 \fB\-maxtxfee=\fR<amt>
 .IP
-Maximum total fees (in BCC) to use in a single wallet transaction or raw
+Maximum total fees (in BCH) to use in a single wallet transaction or raw
 transaction; setting this too low may abort large transactions
 (default: 0.10)
 .HP
@@ -419,7 +419,7 @@
 .HP
 \fB\-blockmintxfee=\fR<amt>
 .IP
-Set lowest fee rate (in BCC/kB) for transactions to be included in block
+Set lowest fee rate (in BCH/kB) for transactions to be included in block
 creation. (default: 0.00001)
 .PP
 RPC server options:
diff --git a/src/amount.h b/src/amount.h
--- a/src/amount.h
+++ b/src/amount.h
@@ -111,7 +111,7 @@
  * No amount larger than this (in satoshi) is valid.
  *
  * Note that this constant is *not* the total money supply, which in Bitcoin
- * currently happens to be less than 21,000,000 BCC for various reasons, but
+ * currently happens to be less than 21,000,000 BCH for various reasons, but
  * rather a sanity check. As this sanity check is used by consensus-critical
  * validation code, the exact value of the MAX_MONEY constant is consensus
  * critical; in unusual circumstances like a(nother) overflow bug that allowed
diff --git a/src/amount.cpp b/src/amount.cpp
--- a/src/amount.cpp
+++ b/src/amount.cpp
@@ -7,7 +7,7 @@
 
 #include "tinyformat.h"
 
-const std::string CURRENCY_UNIT = "BCC";
+const std::string CURRENCY_UNIT = "BCH";
 
 std::string Amount::ToString() const {
     return strprintf("%d.%08d %s", amount / COIN.GetSatoshis(),
diff --git a/src/qt/bitcoinamountfield.cpp b/src/qt/bitcoinamountfield.cpp
--- a/src/qt/bitcoinamountfield.cpp
+++ b/src/qt/bitcoinamountfield.cpp
@@ -23,7 +23,7 @@
 
 public:
     explicit AmountSpinBox(QWidget *parent)
-        : QAbstractSpinBox(parent), currentUnit(BitcoinUnits::BCC),
+        : QAbstractSpinBox(parent), currentUnit(BitcoinUnits::BCH),
           singleStep(100000 /* satoshis */) {
         setAlignment(Qt::AlignRight);
 
@@ -89,7 +89,7 @@
             const QFontMetrics fm(fontMetrics());
             int h = lineEdit()->minimumSizeHint().height();
             int w = fm.width(BitcoinUnits::format(
-                BitcoinUnits::BCC, BitcoinUnits::maxMoney(), false,
+                BitcoinUnits::BCH, BitcoinUnits::maxMoney(), false,
                 BitcoinUnits::separatorAlways));
             // Cursor blinking space.
             w += 2;
diff --git a/src/qt/bitcoinunits.h b/src/qt/bitcoinunits.h
--- a/src/qt/bitcoinunits.h
+++ b/src/qt/bitcoinunits.h
@@ -56,7 +56,7 @@
      * @note Source: https://en.bitcoin.it/wiki/Units.
      * Please add only sensible ones.
      */
-    enum Unit { BCC, mBCC, uBCC };
+    enum Unit { BCH, mBCH, uBCH };
 
     enum SeparatorStyle { separatorNever, separatorStandard, separatorAlways };
 
diff --git a/src/qt/bitcoinunits.cpp b/src/qt/bitcoinunits.cpp
--- a/src/qt/bitcoinunits.cpp
+++ b/src/qt/bitcoinunits.cpp
@@ -13,17 +13,17 @@
 
 QList<BitcoinUnits::Unit> BitcoinUnits::availableUnits() {
     QList<BitcoinUnits::Unit> unitlist;
-    unitlist.append(BCC);
-    unitlist.append(mBCC);
-    unitlist.append(uBCC);
+    unitlist.append(BCH);
+    unitlist.append(mBCH);
+    unitlist.append(uBCH);
     return unitlist;
 }
 
 bool BitcoinUnits::valid(int unit) {
     switch (unit) {
-        case BCC:
-        case mBCC:
-        case uBCC:
+        case BCH:
+        case mBCH:
+        case uBCH:
             return true;
         default:
             return false;
@@ -32,12 +32,12 @@
 
 QString BitcoinUnits::name(int unit) {
     switch (unit) {
-        case BCC:
-            return QString("BCC");
-        case mBCC:
-            return QString("mBCC");
-        case uBCC:
-            return QString::fromUtf8("μBCC");
+        case BCH:
+            return QString("BCH");
+        case mBCH:
+            return QString("mBCH");
+        case uBCH:
+            return QString::fromUtf8("μBCH");
         default:
             return QString("???");
     }
@@ -45,11 +45,11 @@
 
 QString BitcoinUnits::description(int unit) {
     switch (unit) {
-        case BCC:
+        case BCH:
             return QString("Bitcoins");
-        case mBCC:
+        case mBCH:
             return QString("Milli-Bitcoins (1 / 1" THIN_SP_UTF8 "000)");
-        case uBCC:
+        case uBCH:
             return QString("Micro-Bitcoins (1 / 1" THIN_SP_UTF8
                            "000" THIN_SP_UTF8 "000)");
         default:
@@ -59,11 +59,11 @@
 
 qint64 BitcoinUnits::factor(int unit) {
     switch (unit) {
-        case BCC:
+        case BCH:
             return 100000000;
-        case mBCC:
+        case mBCH:
             return 100000;
-        case uBCC:
+        case uBCH:
             return 100;
         default:
             return 100000000;
@@ -72,11 +72,11 @@
 
 int BitcoinUnits::decimals(int unit) {
     switch (unit) {
-        case BCC:
+        case BCH:
             return 8;
-        case mBCC:
+        case mBCH:
             return 5;
-        case uBCC:
+        case uBCH:
             return 2;
         default:
             return 0;
diff --git a/src/qt/coincontroldialog.cpp b/src/qt/coincontroldialog.cpp
--- a/src/qt/coincontroldialog.cpp
+++ b/src/qt/coincontroldialog.cpp
@@ -584,7 +584,7 @@
     }
 
     // actually update labels
-    int nDisplayUnit = BitcoinUnits::BCC;
+    int nDisplayUnit = BitcoinUnits::BCH;
     if (model && model->getOptionsModel()) {
         nDisplayUnit = model->getOptionsModel()->getDisplayUnit();
     }
diff --git a/src/qt/guiutil.cpp b/src/qt/guiutil.cpp
--- a/src/qt/guiutil.cpp
+++ b/src/qt/guiutil.cpp
@@ -192,7 +192,7 @@
             fShouldReturnFalse = false;
         } else if (i->first == "amount") {
             if (!i->second.isEmpty()) {
-                if (!BitcoinUnits::parse(BitcoinUnits::BCC, i->second,
+                if (!BitcoinUnits::parse(BitcoinUnits::BCH, i->second,
                                          &rv.amount)) {
                     return false;
                 }
@@ -230,7 +230,7 @@
     if (info.amount) {
         ret +=
             QString("?amount=%1")
-                .arg(BitcoinUnits::format(BitcoinUnits::BCC, info.amount, false,
+                .arg(BitcoinUnits::format(BitcoinUnits::BCH, info.amount, false,
                                           BitcoinUnits::separatorNever));
         paramCount++;
     }
diff --git a/src/qt/optionsmodel.cpp b/src/qt/optionsmodel.cpp
--- a/src/qt/optionsmodel.cpp
+++ b/src/qt/optionsmodel.cpp
@@ -74,7 +74,7 @@
 
     // Display
     if (!settings.contains("nDisplayUnit")) {
-        settings.setValue("nDisplayUnit", BitcoinUnits::BCC);
+        settings.setValue("nDisplayUnit", BitcoinUnits::BCH);
     }
     nDisplayUnit = settings.value("nDisplayUnit").toInt();
 
diff --git a/src/qt/sendcoinsentry.cpp b/src/qt/sendcoinsentry.cpp
--- a/src/qt/sendcoinsentry.cpp
+++ b/src/qt/sendcoinsentry.cpp
@@ -113,7 +113,7 @@
     ui->memoTextLabel_s->clear();
     ui->payAmount_s->clear();
 
-    // update the display unit, to not use the default ("BCC")
+    // update the display unit, to not use the default ("BCH")
     updateDisplayUnit();
 }
 
diff --git a/src/qt/test/paymentrequestdata.h b/src/qt/test/paymentrequestdata.h
--- a/src/qt/test/paymentrequestdata.h
+++ b/src/qt/test/paymentrequestdata.h
@@ -427,7 +427,7 @@
 ";
 
 //
-// Payment request with amount overflow (amount is set to 21000001 BCC)
+// Payment request with amount overflow (amount is set to 21000001 BCH)
 //
 const char *paymentrequest5_cert2_BASE64 = "\
 Egt4NTA5K3NoYTI1NhrQBArNBDCCAkkwggExoAMCAQICAQEwDQYJKoZIhvcNAQEL\
diff --git a/src/test/compress_tests.cpp b/src/test/compress_tests.cpp
--- a/src/test/compress_tests.cpp
+++ b/src/test/compress_tests.cpp
@@ -17,10 +17,10 @@
 #define NUM_MULTIPLES_CENT 10000
 
 // amounts 1 .. 10000
-#define NUM_MULTIPLES_1BCC 10000
+#define NUM_MULTIPLES_1BCH 10000
 
 // amounts 50 .. 21000000
-#define NUM_MULTIPLES_50BCC 420000
+#define NUM_MULTIPLES_50BCH 420000
 
 BOOST_FIXTURE_TEST_SUITE(compress_tests, BasicTestingSetup)
 
@@ -55,11 +55,11 @@
         BOOST_CHECK(TestEncode(i * CENT));
     }
 
-    for (int64_t i = 1; i <= NUM_MULTIPLES_1BCC; i++) {
+    for (int64_t i = 1; i <= NUM_MULTIPLES_1BCH; i++) {
         BOOST_CHECK(TestEncode(i * COIN));
     }
 
-    for (int64_t i = 1; i <= NUM_MULTIPLES_50BCC; i++) {
+    for (int64_t i = 1; i <= NUM_MULTIPLES_50BCH; i++) {
         BOOST_CHECK(TestEncode(i * 50 * COIN));
     }
diff --git a/src/qt/overviewpage.cpp b/src/qt/overviewpage.cpp
--- a/src/qt/overviewpage.cpp
+++ b/src/qt/overviewpage.cpp
@@ -26,7 +26,7 @@
 public:
     TxViewDelegate(const PlatformStyle *_platformStyle,
                    QObject *parent = nullptr)
-        : QAbstractItemDelegate(parent), unit(BitcoinUnits::BCC),
+        : QAbstractItemDelegate(parent), unit(BitcoinUnits::BCH),
           platformStyle(_platformStyle) {}
 
     inline void paint(QPainter *painter, const QStyleOptionViewItem &option,
@@ -264,7 +264,7 @@
                 SLOT(updateWatchOnlyLabels(bool)));
     }
 
     // update the display unit, to not use the default ("BCC")
     updateDisplayUnit();
 }
 
@@ -264,7 +264,7 @@
     }
 
-    // update the display unit, to not use the default ("BCC")
+    // update the display unit, to not use the default ("BCH")
     updateDisplayUnit();
 }